@@ -25,8 +25,19 @@ if { [string compare $cmd "create"] == 0 } {
         error "ERROR: Invalid number of arguments for the modify operation"
         exit
     }
-    set xci_name [lindex $argv 2]
-    read_ip $xci_name
+
+    set src_file [lindex $argv 2]
+    set src_ext [file extension $src_file ]
+    if [expr [lsearch {.xci} $src_ext] >= 0] {
+        read_ip $src_file
+    } elseif [expr [lsearch {.bd} $src_ext] >= 0] {
+        add_files -norecurse $src_file
+        export_ip_user_files -of_objects  [get_files $src_file] -force -quiet
+        open_bd_design $src_file
+    } else {
+        puts "ERROR: Invalid file extension: $src_ext"
+    }
+
 } elseif { [string compare $cmd "list"] == 0 } {
     puts "Supported IP for device ${part_name}:"
     foreach ip [lsort [get_ipdefs]] {
@@ -37,8 +48,8 @@ if { [string compare $cmd "create"] == 0 } {
         error "ERROR: Invalid number of arguments for the upgrade operation"
         exit
     }
-    set xci_name [lindex $argv 2]
-    read_ip $xci_name
+    set src_file [lindex $argv 2]
+    read_ip $src_file
     upgrade_ip [get_ips *]
 } else {
     error "ERROR: Invalid command: $cmd"
